import{b as f,e6 as o,ek as u}from"./index.e310aebb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="fb246de8-4643-4ded-a162-71fcf0f7bd36",e._sentryDebugIdIdentifier="sentry-dbid-fb246de8-4643-4ded-a162-71fcf0f7bd36")}catch{}})();function a(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(d){return Object.getOwnPropertyDescriptor(n,d).enumerable}))),r.forEach(function(d){l(e,d,n[d])})}return e}function l(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var i=function(t,n){var r=a({},t,n.attrs);return f(o,a({},r,{icon:u}),null)};i.displayName="LoadingOutlined";i.inheritAttrs=!1;const s=i;export{s as L};
//# sourceMappingURL=LoadingOutlined.c81a4534.js.map
