import"./index.e310aebb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="34d2cb38-2171-4190-943b-a60fb0db4476",e._sentryDebugIdIdentifier="sentry-dbid-34d2cb38-2171-4190-943b-a60fb0db4476")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}},b=(e,r)=>{if(!Object.keys(r).length)return e;const t=new URL(e),n=new URLSearchParams(t.search);return Object.entries(r).forEach(([s,a])=>{t.searchParams.delete(s),n.set(s,a)}),`${t.origin}${t.pathname}?${n.toString()}`};export{d as i,b as m};
//# sourceMappingURL=url.fb968ca0.js.map
