import{b as f,e6 as u,d as i,o as s,c as p,w as c,u as l,O as b,K as m,az as g,aL as h,bM as y}from"./index.e310aebb.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="2470366e-93ab-45f4-8920-ef3dd126fd4f",t._sentryDebugIdIdentifier="sentry-dbid-2470366e-93ab-45f4-8920-ef3dd126fd4f")}catch{}})();var O={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M832 64H192c-17.7 0-32 14.3-32 32v832c0 17.7 14.3 32 32 32h640c17.7 0 32-14.3 32-32V96c0-17.7-14.3-32-32-32zm-260 72h96v209.9L621.5 312 572 347.4V136zm220 752H232V136h280v296.9c0 3.3 1 6.6 3 9.3a15.9 15.9 0 0022.3 3.7l83.8-59.9 81.4 59.4c2.7 2 6 3.1 9.4 3.1 8.8 0 16-7.2 16-16V136h64v752z"}}]},name:"book",theme:"outlined"};const v=O;function d(t){for(var e=1;e<arguments.length;e++){var n=arguments[e]!=null?Object(arguments[e]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(o){return Object.getOwnPropertyDescriptor(n,o).enumerable}))),r.forEach(function(o){_(t,o,n[o])})}return t}function _(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var a=function(e,n){var r=d({},e,n.attrs);return f(u,d({},r,{icon:v}),null)};a.displayName="BookOutlined";a.inheritAttrs=!1;const k=a,w=i({__name:"DocsButton",props:{path:{}},setup(t){return(e,n)=>{var r;return s(),p(l(y),{class:"docs-button",href:`https://abstra.io/docs/${(r=e.path)!=null?r:""}`,target:"_blank",type:"text",size:"small"},{icon:c(()=>[f(l(k))]),default:c(()=>[e.$slots.default?b(e.$slots,"default",{key:0}):(s(),m(h,{key:1},[g("Docs")],64))]),_:3},8,["href"])}}});export{w as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.d13fff5d.js.map
