[data-v-3856aa88]:root{--main-font-family: DM Sans, sans-serif}[data-v-3856aa88]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-3856aa88]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-3856aa88]{background-color:#fff;padding:10px}.action-icons svg[data-v-3856aa88]{cursor:pointer;color:#000}.action-icons .filled[data-v-3856aa88]{color:#d14056;pointer-events:none}.action-icons .disabled[data-v-3856aa88]{opacity:.5;pointer-events:none}.action-icons .icon[data-v-3856aa88]{cursor:pointer;outline:none}.action-icons .icon.disabled[data-v-3856aa88]{opacity:.2;pointer-events:none}.action-icons .icon[data-v-3856aa88]:hover{background:rgba(255,255,255,.2);border-radius:4px}.upper[data-v-858be1b0]{width:100%;padding:4px 12px}.upper .recent-container[data-v-858be1b0]{overflow:scroll}.upper .recent-container[data-v-858be1b0]::-webkit-scrollbar{display:none}.upper .recent-container .recent-thread[data-v-858be1b0]{cursor:pointer}.upper .recent-container .current-thread[data-v-858be1b0]{border-color:#d1405675}.upper[data-v-858be1b0] .ant-btn{height:fit-content}.upper[data-v-858be1b0] .ant-btn-icon-only{display:flex;justify-content:center;align-items:center;width:22px}.lower[data-v-64014456]{border:1px solid #f0f0f0;border-radius:10px;width:calc(25vw - 20px);margin:10px 0}.lower .bottom-lower[data-v-64014456]{padding:6px}.lower .bottom-lower .info[data-v-64014456]{display:flex;gap:8px;padding-left:4px}[data-v-388e388d]:root{--main-font-family: DM Sans, sans-serif}[data-v-388e388d]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-388e388d]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-388e388d]{background-color:#fff;padding:10px}.suggestions-container[data-v-388e388d]{width:calc(25vw - 40px);height:100%;padding:8px}.suggestions-container .suggestion[data-v-388e388d]{display:flex;align-items:center;gap:10px;border-radius:8px;background-color:#f9fafb;padding:16px;cursor:pointer;transition:all .2s}.suggestions-container .suggestion[data-v-388e388d]:hover{background-color:#f3f3f3}.suggestions-container .suggestion .icon[data-v-388e388d]{height:24px;width:24px;color:#d14056}.suggestions-container .suggestion .title[data-v-388e388d]{font-size:15px;color:#000}.copy-button[data-v-9f87bac2]{position:absolute;top:12px;right:12px;cursor:pointer;outline:none}.container[data-v-4deba69c]{display:flex;flex-direction:column;justify-content:space-between;align-items:center;height:100%;width:0;border-left:1px solid #f0f0f0;transition:width .3s ease;overflow:hidden;background-color:#fff}.container.visible[data-v-4deba69c]{width:25vw;overflow:visible}.container .content[data-v-4deba69c]{flex:1;flex-direction:column;overflow-y:hidden;padding:0 14px;text-align:left;width:25vw}.container .content .scroll[data-v-4deba69c]{overflow-y:auto}.container .content .scroll[data-v-4deba69c]::-webkit-scrollbar{display:none}.container .content .empty-container[data-v-4deba69c]{height:100%}.container .content .entry[data-v-4deba69c]{padding-top:4px;padding-bottom:12px}.container .content .entry .entry-owner[data-v-4deba69c]{display:flex;gap:4px;align-items:center;margin-bottom:4px}.container .content .entry .entry-owner .avatar[data-v-4deba69c]{display:flex;justify-content:center;align-items:center;margin-right:2px;font-size:12px!important}.container .content .timeline-item[data-v-4deba69c]{padding-right:10px}.container .content .timeline-item .remove-action[data-v-4deba69c]{display:none}.container .content .timeline-item[data-v-4deba69c]:hover{padding-right:0}.container .content .timeline-item:hover .remove-action[data-v-4deba69c]{display:block;cursor:pointer;color:#505050}.container .content .timeline-item:hover .remove-action[data-v-4deba69c]:hover{color:#101010}.container .scroll-to-bottom[data-v-4deba69c]{display:flex;align-items:center;justify-content:center;position:absolute;right:8px;bottom:175px;width:32px;height:32px;background:white;border-radius:50%;padding:4px;box-shadow:#0003 0 0 4px}
