@media screen and (max-width: 1024px){[data-v-8c65d618] .scroll-area{flex-direction:column}}.row[data-v-8c65d618]{display:flex;gap:20px;height:auto}.row *[data-v-8c65d618]{flex-basis:0;flex-grow:1}.header[data-v-8c65d618]{display:flex;justify-content:space-between}.editing-content[data-v-8c65d618]{border-radius:6px;flex-grow:1;flex-basis:0}.files-nav[data-v-8c65d618]{max-height:100%;overflow:auto;flex-grow:1;flex-basis:0}
