import{O as r}from"./userStore.e6231111.js";import{d as l,J as c,K as u,b as a,w as n,u as o,o as i,az as d,d6 as f,d5 as _}from"./index.e310aebb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="21ec1e06-9b7d-46ad-88df-c0599089cfac",e._sentryDebugIdIdentifier="sentry-dbid-21ec1e06-9b7d-46ad-88df-c0599089cfac")}catch{}})();const p=l({__name:"OidcLogoutCallback",setup(e){return c(async()=>{await new r().logoutCallback()}),(t,s)=>(i(),u("div",null,[a(o(f),null,{default:n(()=>[d("You're authenticated")]),_:1}),a(o(_),null,{default:n(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLogoutCallback.4c405ab2.js.map
