import{d as k,f as B,J as A,o as n,c as u,w as f,b as I,az as P,eb as S,ec as C,ef as D,u as y,bM as N,eZ as x,Q as h,e4 as V,F as g,a as b,K as c,ea as v,eh as q,aL as w,v as E,x as L}from"./index.e310aebb.js";import{S as F}from"./Steps.32c7dd17.js";import{W as K}from"./PlayerConfigProvider.4862e88a.js";import"./index.3752b014.js";import"./colorHelpers.0fc16894.js";import"./index.f0e26865.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="1b05b011-f2fe-4a70-a512-f77054043a42",o._sentryDebugIdIdentifier="sentry-dbid-1b05b011-f2fe-4a70-a512-f77054043a42")}catch{}})();const $=k({__name:"ActionButton",props:{action:{},displayName:{},disabled:{type:Boolean},loading:{type:Boolean}},emits:["click"],setup(o,{emit:t}){const d=o,l=B(null);return A(()=>{l.value&&d.action.setElement(l.value)}),(a,i)=>(n(),u(y(x),null,{default:f(()=>[I(y(N),{ref_key:"element",ref:l,class:C(["next-button",a.disabled?"disabled":""]),loading:a.loading,disabled:a.disabled,onClick:i[0]||(i[0]=p=>t("click")),onKeydown:i[1]||(i[1]=D(p=>t("click"),["enter"]))},{default:f(()=>[P(S(a.displayName),1)]),_:1},8,["loading","disabled","class"])]),_:1}))}});const M=h($,[["__scopeId","data-v-aea27bb7"]]),z={class:"form"},J={class:"form-wrapper"},O={key:0,class:"buttons"},Q=k({__name:"WidgetPreview",setup(o){const t=V(),d=B([]);function l(e){return E[e]||L[e]||null}function a(e){try{const s=JSON.parse(e);if(s.component=l(s.type),!s.component)throw new Error(`Widget ${s.type} not found`);return s.component?s:null}catch{return null}}function i(){const e=t.query.widget;return Array.isArray(e)?e.map(a).filter(Boolean):[a(e)]}function p(){return t.query.steps==="true"}function m(){const e=t.query.button;return e?Array.isArray(e)?e:[e]:[]}const _=e=>({name:e,isDefault:!1,isFocused:!1,focusOnButton:()=>{},addKeydownListener:()=>{},setElement:()=>{}});return(e,s)=>(n(),u(K,{"main-color":"#d14056",class:"preview",background:"#fbfbfb","font-family":"Inter",locale:"en"},{default:f(()=>[p()?(n(),u(F,{key:0,class:"steps","steps-info":{current:1,total:3},"is-preview":""})):g("",!0),b("div",z,[b("div",J,[(n(!0),c(w,null,v(i(),(r,W)=>(n(),c("div",{key:W,class:"widget"},[(n(),u(q(r.component),{"user-props":r.userProps,value:r.userProps.value,errors:d.value},null,8,["user-props","value","errors"]))]))),128))]),m().length?(n(),c("div",O,[(n(!0),c(w,null,v(m(),r=>(n(),u(M,{key:r,"display-name":_(r).name,action:_(r)},null,8,["display-name","action"]))),128))])):g("",!0)])]),_:1}))}});const U=h(Q,[["__scopeId","data-v-e1ac7894"]]);export{U as default};
//# sourceMappingURL=WidgetPreview.5eb4ad5b.js.map
