import{Q as c,o,K as n,O as s,a as d,F as a}from"./index.e310aebb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="7a652bef-6b07-4372-8c3e-062b46bcf149",e._sentryDebugIdIdentifier="sentry-dbid-7a652bef-6b07-4372-8c3e-062b46bcf149")}catch{}})();const r={},i={class:"base-layout"},f={class:"base-middle"},_={class:"content"},l={class:"left"},u={key:0,class:"base-footer"},b={key:0};function y(e,t){return o(),n("div",i,[s(e.$slots,"sidebar",{},void 0,!0),d("section",f,[s(e.$slots,"navbar",{},void 0,!0),d("section",_,[d("section",l,[s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(o(),n("section",u,[s(e.$slots,"footer",{},void 0,!0)])):a("",!0)]),e.$slots.chat?(o(),n("section",b,[s(e.$slots,"chat",{},void 0,!0)])):a("",!0)])])])}const g=c(r,[["render",y],["__scopeId","data-v-fe23e6dd"]]);export{g as B};
//# sourceMappingURL=BaseLayout.282c61a4.js.map
