[data-v-001b8cf4]:root{--abstra-main-color-dark: #343b46}.linter-btn.info[data-v-001b8cf4]{color:#44a5ff;border-color:#44a5ff}.linter-btn.info[data-v-001b8cf4]:hover,.linter-btn.info[data-v-001b8cf4]:active{color:#44a5ff;border-color:#44a5ff;background-color:#e6f4ff}.linter-btn.warning[data-v-001b8cf4]{color:#ffc400;border-color:#ffc400}.linter-btn.warning[data-v-001b8cf4]:hover,.linter-btn.warning[data-v-001b8cf4]:active{color:#ffc400;border-color:#ffc400;background-color:#fffbe6}.linter-btn.error[data-v-001b8cf4]{color:#ff4f3e;border-color:#ff4f3e}.linter-btn.error[data-v-001b8cf4]:hover,.linter-btn.error[data-v-001b8cf4]:active{color:#ff4f3e;border-color:#ff4f3e;background-color:#d3524914}.navbar-right[data-v-3f730c47]{padding:0 10px;justify-self:end}.deploying-animation[data-v-3f730c47]{animation:shake-3f730c47 .5s infinite}@keyframes shake-3f730c47{0%{transform:translate(0)}25%{transform:translate(-2px)}50%{transform:translate(2px)}75%{transform:translate(-2px)}to{transform:translate(0)}}.navbar[data-v-2c9ffe9e]{padding:5px 10px;border:1px solid #f0f0f0;box-sizing:border-box;width:100%;display:flex;justify-content:space-between}.navbar .menu[data-v-2c9ffe9e]{position:absolute;left:50%;transform:translate(-50%)}
