import{n as r,a as i}from"./string.a01d17aa.js";import"./index.e310aebb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="8702a7b5-3670-4b7c-9587-f9c8b094677b",e._sentryDebugIdIdentifier="sentry-dbid-8702a7b5-3670-4b7c-9587-f9c8b094677b")}catch{}})();function o(e){return e.replace(/\.py$/,"").trim().length===0?{valid:!1,reason:"File name cannot be empty"}:e.length>255?{valid:!1,reason:"File name cannot be longer than 255 characters"}:e.endsWith(".py")?{valid:!0}:{valid:!1,reason:"File name must end with .py"}}function f(e){if(!o(e).valid)throw new Error("Invalid filename");const n=e.slice(0,-3);return r(n,!0,!0,!0,!0)+".py"}function s(e){return e.trim().length===0?{valid:!1,reason:"Path cannot be empty"}:{valid:!0}}function u(e){if(!s(e).valid)throw new Error("Invalid path");return e.split("/").filter(Boolean).map(t=>i(t)).join("/")}export{o as a,f as b,u as n,s as v};
//# sourceMappingURL=validations.6d3f69e1.js.map
