import{L as t}from"./Logo.afdc4154.js";import{d as n,o as r,c as d,u as i}from"./index.e310aebb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="6c8f63de-2096-4e0e-ae3a-ce9621e92a4e",e._sentryDebugIdIdentifier="sentry-dbid-6c8f63de-2096-4e0e-ae3a-ce9621e92a4e")}catch{}})();const f="/assets/logo.0faadfa2.svg",u=n({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(s,o)=>{var a;return r(),d(t,{"image-url":i(f),"brand-name":"Abstra","hide-text":s.hideText,size:(a=s.size)!=null?a:"small"},null,8,["image-url","hide-text","size"])}}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.280ece81.js.map
