import{G as s,dv as i,dw as d}from"./index.e310aebb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="ff423eac-95ec-481a-ae26-a03220307478",e._sentryDebugIdIdentifier="sentry-dbid-ff423eac-95ec-481a-ae26-a03220307478")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:a,YearPicker:f,TimePicker:m,QuarterPicker:r,RangePicker:o}=i(d),y=s(n,{WeekPicker:t,MonthPicker:a,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:r,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(a.name,a),e.component(t.name,t),e.component(r.name,r),e)});export{y as D,a as M,r as Q,o as R,t as W};
//# sourceMappingURL=dayjs.ef81895b.js.map
