import{C as p}from"./controller.b35b6237.js";import{d as i,e4 as n,c as s,u as m,o as a}from"./index.e310aebb.js";import{_ as c}from"./View.vue_vue_type_script_setup_true_lang.4d91a15c.js";import"./gateway.4d0dc75b.js";import"./popupNotifcation.fa3e65fc.js";import"./fetch.ac0cc198.js";import"./record.d2935dfa.js";import"./PhPencil.vue.001dc101.js";import"./SaveButton.3679bfe7.js";import"./UnsavedChangesHandler.b4b7d195.js";import"./ExclamationCircleOutlined.ba1bd806.js";import"./CrudView.f8c62bd5.js";import"./router.2399bbbf.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.d13fff5d.js";import"./url.fb968ca0.js";import"./PhDotsThreeVertical.vue.86ea10eb.js";import"./Badge.a954551a.js";import"./index.3d882fa8.js";import"./index.850d1dd3.js";import"./asyncComputed.6b1d4165.js";import"./polling.debfe6c7.js";import"./omniChatStore.755c548d.js";import"./index.1acd89cf.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="886c2e8f-fef9-4f90-90cc-7195578531ea",o._sentryDebugIdIdentifier="sentry-dbid-886c2e8f-fef9-4f90-90cc-7195578531ea")}catch{}})();const F=i({__name:"EnvVars",setup(o){const e=n().params.projectId,t=new p(e);return(f,d)=>(a(),s(c,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{F as default};
//# sourceMappingURL=EnvVars.1b6ba1d0.js.map
