import{C as t}from"./gateway.4d0dc75b.js";import"./index.e310aebb.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="7c5107d6-64c3-4347-945e-e6020b996504",r._sentryDebugIdIdentifier="sentry-dbid-7c5107d6-64c3-4347-945e-e6020b996504")}catch{}})();class a{async list(e){return t.get(`organizations/${e}/folders`)}async create(e){return t.post(`organizations/${e.organizationId}/folders`,{name:e.name,memberIds:e.memberIds})}async delete(e,n){return t.delete(`organizations/${e}/folders/${n}`)}async update(e,n){return t.patch(`organizations/${e}/folders/${n.id}/`,{name:n.name,memberIds:n.memberIds})}}export{a as F};
//# sourceMappingURL=folder.c01eb2d9.js.map
