import{b as l,e6 as o,eK as f}from"./index.e310aebb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9c5f6b72-d4a6-4b11-882c-7942838f22cc",e._sentryDebugIdIdentifier="sentry-dbid-9c5f6b72-d4a6-4b11-882c-7942838f22cc")}catch{}})();function a(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(c){return Object.getOwnPropertyDescriptor(n,c).enumerable}))),r.forEach(function(c){u(e,c,n[c])})}return e}function u(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var i=function(t,n){var r=a({},t,n.attrs);return l(o,a({},r,{icon:f}),null)};i.displayName="ExclamationCircleOutlined";i.inheritAttrs=!1;const s=i;export{s as E};
//# sourceMappingURL=ExclamationCircleOutlined.ba1bd806.js.map
