import{C as t}from"./gateway.4d0dc75b.js";import"./index.e310aebb.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="c11ba93d-e5b4-4a94-bb54-afae073d4df3",a._sentryDebugIdIdentifier="sentry-dbid-c11ba93d-e5b4-4a94-bb54-afae073d4df3")}catch{}})();class i{async create(e){return t.post(`organizations/${e.organizationId}/members`,{email:e.email,teams:e.teams})}async delete(e){return t.delete(`organizations/${e.organizationId}/members/${e.authorId}`)}async list(e){return t.get(`organizations/${e}/members`)}async get(e,n){return t.get(`organizations/${e}/members/${n}`)}async update(e,n,r){return t.patch(`organizations/${e}/members/${n}`,r)}}export{i as M};
//# sourceMappingURL=member.c84b9c44.js.map
