import{i as h}from"./metadata.0be16082.js";import{W as k}from"./Watermark.8ab5e319.js";import{F as b}from"./PhArrowSquareOut.vue.2585952a.js";import{d as w,e3 as v,g as x,f as C,u as e,K as f,b as p,w as r,F as z,o as a,c as n,az as m,d2 as y,aL as D,ea as I,da as _,eh as F,eb as L,ec as T,Q as B}from"./index.e310aebb.js";import{u as H}from"./workspaceStore.9673015c.js";import"./index.2b4c041b.js";import{L as N}from"./LoadingOutlined.c81a4534.js";import{C as S}from"./Card.adf1677c.js";import"./PhWebhooksLogo.vue.9a797838.js";import"./userStore.e6231111.js";import"./url.fb968ca0.js";import"./colorHelpers.0fc16894.js";import"./TabPane.9d204c54.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="f9c53034-1fe7-40bd-b50d-965973e8f9b0",o._sentryDebugIdIdentifier="sentry-dbid-f9c53034-1fe7-40bd-b50d-965973e8f9b0")}catch{}})();const V={key:0,class:"home-container"},W=w({__name:"Home",setup(o){const i=v(),l=H(),u=x(()=>{var s;return((s=l.state.workspace)==null?void 0:s.sidebar.filter(d=>d.id!=="home"))||[]}),c=C(null),g=async(s,d)=>{c.value=d,await i.push({path:`/${s}`}),c.value=null};return(s,d)=>e(l).state.workspace?(a(),f("div",V,[p(e(_),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[u.value.length===0?(a(),n(e(y),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[m(" There are no forms available for you. ")]),_:1})):(a(!0),f(D,{key:1},I(u.value,t=>(a(),n(e(S),{key:t.id,class:T(["form-card",{loading:c.value===t.id}]),"body-style":{cursor:"pointer"},onClick:E=>g(t.path,t.id)},{default:r(()=>[p(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(a(),n(F(e(h)(t.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),p(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[m(L(t.name),1)]),_:2},1024),c.value!==t.id?(a(),n(e(b),{key:0,size:"20"})):(a(),n(e(N),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),p(k,{class:"watermark","page-id":"home",locale:e(l).state.workspace.language},null,8,["locale"])])):z("",!0)}});const X=B(W,[["__scopeId","data-v-060376d1"]]);export{X as default};
//# sourceMappingURL=Home.4522eeea.js.map
