import{_ as k}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.280ece81.js";import{d as v,e4 as A,e3 as x,g as w,K as I,b as c,w as a,u as e,c as p,F as f,o as i,az as s,eb as l,d6 as C,d2 as m,bM as N,a as B,d3 as D,eg as o,Q as T}from"./index.e310aebb.js";import{u as E}from"./workspaceStore.9673015c.js";import{C as V}from"./Card.adf1677c.js";import"./Logo.afdc4154.js";import"./userStore.e6231111.js";import"./url.fb968ca0.js";import"./colorHelpers.0fc16894.js";import"./TabPane.9d204c54.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new $().stack;d&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[d]="26b7a57b-3e8b-46dc-849a-4c4a9719fe36",r._sentryDebugIdIdentifier="sentry-dbid-26b7a57b-3e8b-46dc-849a-4c4a9719fe36")}catch{}})();const S={class:"inner-content"},H={class:"card-content"},R=v({__name:"Error",setup(r){const d=A(),b=x(),u=E(),g=w(()=>{var t,_,y;return(y=(t=u.state.workspace)==null?void 0:t.name)!=null?y:(_=u.state.workspace)==null?void 0:_.brandName}),n=w(()=>{const{status:t}=d.params;switch(t){case"404":return{status:t,title:o.translate("i18n_page_not_found"),message:o.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:t,title:o.translate("i18n_access_denied"),message:o.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:o.translate("i18n_internal_error"),message:o.translate("i18n_internal_error_message"),showAd:!1}}}),h=()=>{b.push({name:"playerHome"})};return(t,_)=>(i(),I("div",S,[c(e(C),null,{default:a(()=>[s(l(n.value.title),1)]),_:1}),c(e(m),{class:"message"},{default:a(()=>[s(l(n.value.message),1)]),_:1}),n.value.action?(i(),p(e(N),{key:0,type:"link",onClick:h},{default:a(()=>[s(l(n.value.action),1)]),_:1})):f("",!0),n.value.showAd?(i(),p(e(V),{key:1,bordered:!1,class:"card"},{default:a(()=>[B("div",H,[c(k,{style:{"margin-bottom":"10px"}}),c(e(m),null,{default:a(()=>[s("This page is part of "+l(g.value?`the ${g.value}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(u).state.workspace?(i(),p(e(m),{key:0},{default:a(()=>[s("Automate your own processes by getting started "),c(e(D),{href:"https://abstra.io"},{default:a(()=>[s("here")]),_:1}),s(".")]),_:1})):f("",!0)])]),_:1})):f("",!0)]))}});const $=T(R,[["__scopeId","data-v-f16a0b67"]]);export{$ as default};
//# sourceMappingURL=Error.00d2a7fe.js.map
