import{P as f}from"./PlayerNavbar.8c0bedd6.js";import{d as g,e3 as h,e4 as c,f as b,g as y,r as k,K as v,u as a,c as w,F as L,a as C,b as I,o as i,Q as N}from"./index.e310aebb.js";import{u as V}from"./workspaceStore.9673015c.js";import"./userStore.e6231111.js";import"./metadata.0be16082.js";import"./PhWebhooksLogo.vue.9a797838.js";import"./LoadingOutlined.c81a4534.js";import"./PhSignOut.vue.024a2a22.js";import"./index.baae1682.js";import"./Avatar.004ed8a2.js";import"./url.fb968ca0.js";import"./colorHelpers.0fc16894.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="c86888fb-eb15-4cf3-9943-4e62bd52296a",o._sentryDebugIdIdentifier="sentry-dbid-c86888fb-eb15-4cf3-9943-4e62bd52296a")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),u=c().path,n=b(null),d=async({path:r,id:s})=>{n.value=s,await e.push({path:`/${r}`}),n.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=y(()=>!!c().meta.hideLogin);return(r,s)=>{const m=k("RouterView");return i(),v("div",x,[a(t).state.workspace?(i(),w(f,{key:0,"current-path":a(u),"hide-login":_.value,"runner-data":a(t).state.workspace,loading:n.value,onNavigate:d,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const z=N(D,[["__scopeId","data-v-f095bece"]]);export{z as default};
//# sourceMappingURL=Main.701025bb.js.map
