import{u as w,A as r,a as A}from"./Avatar.004ed8a2.js";import{d as I,a9 as $,g as k,aE as D,bO as E,aw as G,ay as O,b as l,cH as _,ac as c}from"./index.e310aebb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="c8fb7f18-ba8e-47bb-8744-eb2d4c2d1b53",e._sentryDebugIdIdentifier="sentry-dbid-c8fb7f18-ba8e-47bb-8744-eb2d4c2d1b53")}catch{}})();const j=()=>({prefixCls:String,maxCount:Number,maxStyle:{type:Object,default:void 0},maxPopoverPlacement:{type:String,default:"top"},maxPopoverTrigger:String,size:{type:[Number,String,Object],default:"default"},shape:{type:String,default:"circle"}}),N=I({compatConfig:{MODE:3},name:"AAvatarGroup",inheritAttrs:!1,props:j(),setup(e,n){let{slots:m,attrs:t}=n;const{prefixCls:y,direction:v}=$("avatar",e),i=k(()=>`${y.value}-group`),[b,h]=w(y);return D(()=>{const u={size:e.size,shape:e.shape};A(u)}),()=>{const{maxPopoverPlacement:u="top",maxCount:a,maxStyle:x,maxPopoverTrigger:S="hover",shape:C}=e,g={[i.value]:!0,[`${i.value}-rtl`]:v.value==="rtl",[`${t.class}`]:!!t.class,[h.value]:!0},P=E(m,e),s=G(P).map((o,p)=>O(o,{key:`avatar-key-${p}`})),d=s.length;if(a&&a<d){const o=s.slice(0,a),p=s.slice(a,d);return o.push(l(_,{key:"avatar-popover-key",content:p,trigger:S,placement:u,overlayClassName:`${i.value}-popover`},{default:()=>[l(r,{style:x,shape:C},{default:()=>[`+${d-a}`]})]})),b(l("div",c(c({},t),{},{class:g,style:t.style}),[o]))}return b(l("div",c(c({},t),{},{class:g,style:t.style}),[s]))}}}),f=N;r.Group=f;r.install=function(e){return e.component(r.name,r),e.component(f.name,f),e};export{f as G};
//# sourceMappingURL=index.baae1682.js.map
