import{A as o}from"./index.3752b014.js";import{d as r,g as a,K as p,b as f,u as d,ec as c,F as l,o as i,Q as u}from"./index.e310aebb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="7f70f57c-12d0-48b0-b662-47e26d740496",e._sentryDebugIdIdentifier="sentry-dbid-7f70f57c-12d0-48b0-b662-47e26d740496")}catch{}})();const _=r({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,n=a(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(t,b)=>t.stepsInfo?(i(),p("nav",{key:0,class:c(["p-steps",{"full-screen":!t.isPreview}])},[f(d(o),{current:t.stepsInfo.current-1,items:n.value,responsive:!1},null,8,["current","items"])],2)):l("",!0)}});const I=u(_,[["__scopeId","data-v-8b0ea4f1"]]);export{I as S};
//# sourceMappingURL=Steps.32c7dd17.js.map
