import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.280ece81.js";import{B as y}from"./BaseLayout.282c61a4.js";import{d as l,a6 as m,bY as b,Q as u,aT as v,aU as g,o as _,K as h,a as r,N as s,e4 as w,e3 as S,J as k,c as L,w as n,b as i,u as x}from"./index.e310aebb.js";import{u as B}from"./editor.8fcb8d02.js";import{b as I}from"./index.6a1f7c3e.js";import"./Logo.afdc4154.js";import"./userStore.e6231111.js";import"./workspaceStore.9673015c.js";import"./url.fb968ca0.js";import"./colorHelpers.0fc16894.js";import"./linters.686aafeb.js";import"./asyncComputed.6b1d4165.js";import"./index.baae1682.js";import"./Avatar.004ed8a2.js";import"./index.3d882fa8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="9124aa2b-6862-4408-b73b-5788cac2170d",e._sentryDebugIdIdentifier="sentry-dbid-9124aa2b-6862-4408-b73b-5788cac2170d")}catch{}})();const $=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=m({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(o)}}});const P={class:"v-spinner"};function D(e,o,a,c,d,p){return v((_(),h("div",P,[r("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const K=u($,[["render",D],["__scopeId","data-v-06538001"]]),R={class:"content"},j=l({__name:"ProjectLogin",setup(e){const o=w(),a=S(),c=B();function d(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function p(){const t=o.query["api-key"];if(typeof t=="string")return t}return k(async()=>{const t=p();if(!t){a.push({name:"error"});return}await c.createLogin(t).then(d),a.push({name:"workspace"})}),(t,z)=>(_(),L(y,null,{navbar:n(()=>[i(x(I),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:n(()=>[i(f)]),_:1})]),content:n(()=>[r("div",R,[i(K)])]),_:1}))}});const O=u(j,[["__scopeId","data-v-944edebb"]]);export{O as default};
//# sourceMappingURL=ProjectLogin.99bc1341.js.map
