import{d as o,K as n,a as s,O as a,ec as c,o as r,Q as l}from"./index.e310aebb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4833d590-d995-4c99-83b7-cc6fead676dd",e._sentryDebugIdIdentifier="sentry-dbid-4833d590-d995-4c99-83b7-cc6fead676dd")}catch{}})();const _={class:"content-layout"},u=o({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,d)=>(r(),n("div",_,[s("div",{class:c(["centered-layout",{"full-width":t.fullWidth}])},[a(t.$slots,"default",{},void 0,!0)],2)]))}});const f=l(u,[["__scopeId","data-v-6397d501"]]);export{f as C};
//# sourceMappingURL=ContentLayout.991bbf22.js.map
