import{P as f}from"./record.d2935dfa.js";import{e as r,f as a}from"./index.e310aebb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="02f2b17b-e2b2-452e-9a7b-8221f1570e22",e._sentryDebugIdIdentifier="sentry-dbid-02f2b17b-e2b2-452e-9a7b-8221f1570e22")}catch{}})();const i=new f,c=r("omniChat",()=>{const e=a(!1),t=a(!1),n=()=>{t.value=!0},s=()=>{t.value=!1},o=()=>{e.value=!0,n()},u=()=>{e.value=!1,s()};return{isOpen:e,isInputFocused:t,focusInput:n,blurInput:s,open:o,close:u,toggle:()=>{e.value?u():o()}}});export{i as o,c as u};
//# sourceMappingURL=omniChatStore.755c548d.js.map
