.editor-layout[data-v-ea35460f]{width:100%;height:100%;display:flex;gap:20px;overflow:hidden;box-sizing:border-box}.editor-layout .layout-left[data-v-ea35460f],.editor-layout .layout-center[data-v-ea35460f],.editor-layout .layout-right[data-v-ea35460f]{height:100%;box-sizing:border-box;display:flex;flex-direction:column}.editor-layout .layout-left[data-v-ea35460f]{padding:10px 0 10px 20px;width:50%}.editor-layout .layout-center[data-v-ea35460f]{padding:10px 0;width:50%}[data-v-e08ca106]:root{--main-font-family: DM Sans, sans-serif}[data-v-e08ca106]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-e08ca106]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-e08ca106]{background-color:#fff;padding:10px}.header[data-v-e08ca106]{background:#414a58;padding:2px 20px;color:#fff}.header .toggle-button[data-v-e08ca106]{display:flex;border-radius:6px}.header .toggle-button[data-v-e08ca106]:hover{background-color:#fff3}.header .toggle-button .icon[data-v-e08ca106]{transform:rotate(90deg);cursor:pointer;padding:5px;color:#fff;font-size:20px}.header .toggle-button .icon[data-v-e08ca106]:not(.open){transform:rotate(-90deg);transition:transform .4s ease}[data-v-edd3b7c0]:root{--main-font-family: DM Sans, sans-serif}[data-v-edd3b7c0]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-edd3b7c0]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-edd3b7c0]{background-color:#fff;padding:10px}.terminal[data-v-edd3b7c0]{background:#272d35;padding:12px 20px;box-sizing:border-box;position:relative}.terminal .resize-handler[data-v-edd3b7c0]{position:absolute;top:0;left:0;right:0;height:4px;transform:translateY(-50%);cursor:ns-resize;background:transparent}.terminal .resize-handler[data-v-edd3b7c0]:hover,.terminal .resize-handler.resizing[data-v-edd3b7c0]{background:#777}.terminal .cli[data-v-edd3b7c0]{height:100%}.terminal .cli .left[data-v-edd3b7c0]{font-family:Courier New,Courier,monospace;height:100%;width:calc(100% - 40px)}.terminal .cli .left .entries[data-v-edd3b7c0]{display:flex;flex-direction:column;flex-grow:1;overflow-y:scroll;color:#fff}.terminal .cli .left .entries[data-v-edd3b7c0]::-webkit-scrollbar{display:none}.terminal .cli .left .entries .entry[data-v-edd3b7c0]{padding:4px 8px}.terminal .cli .left .entries .entry.stderr[data-v-edd3b7c0],.terminal .cli .left .entries .entry.stdout[data-v-edd3b7c0]{font-family:monospace;white-space:pre-line}.terminal .cli .left .entries .entry.stderr[data-v-edd3b7c0]{color:#f37971}.terminal .cli .left .entries .entry.stdout[data-v-edd3b7c0]{color:#a5dbb7}.terminal .cli .left .entries .entry.ai-output[data-v-edd3b7c0]{color:#e2f371}.terminal .cli .left .entries .icons[data-v-edd3b7c0]{margin-top:-6px;margin-bottom:12px}.terminal .cli .left .entries .icons svg[data-v-edd3b7c0],.terminal .cli .left .entries .icons .icon[data-v-edd3b7c0]{cursor:pointer;padding:2px;border-radius:6px;outline:none;color:#aaa}.terminal .cli .left .entries .icons svg[data-v-edd3b7c0]:hover,.terminal .cli .left .entries .icons .icon[data-v-edd3b7c0]:hover{background:rgba(255,255,255,.2);color:#fff}.terminal .cli .left .entries .icons .filled[data-v-edd3b7c0]{color:#fff;pointer-events:none}.terminal .cli .left .entries .icons .disabled[data-v-edd3b7c0]{opacity:.8;pointer-events:none}.terminal .cli .left .entries .local-entry[data-v-edd3b7c0]{white-space:pre-line;width:100%;overflow-wrap:break-word}.terminal .cli .left .entries .loading[data-v-edd3b7c0]{align-self:center}.terminal .cli .right[data-v-edd3b7c0]{width:30px;margin-left:5px;padding:10px 0}.terminal .cli .right .broom-icon[data-v-edd3b7c0]{cursor:pointer;color:#aaa;outline:none}.terminal .cli .right .broom-icon[data-v-edd3b7c0]:hover{color:#fff}.typing-img[data-v-edd3b7c0]{width:36px;margin:0 0 -10px 20px}.clickable[data-v-18856675]{cursor:pointer;display:flex;align-items:center;gap:10px}.file-path[data-v-18856675]{max-width:360px;margin:0;padding:0;text-align:left;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;direction:rtl}
