import{u as r}from"./userStore.e6231111.js";import{W as n}from"./PlayerConfigProvider.4862e88a.js";import{u as c}from"./workspaceStore.9673015c.js";import{d as f,h as i,r as p,u as o,c as u,w as d,F as l,o as m,b as _}from"./index.e310aebb.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="cf43cf49-168c-4157-a9f0-8c25f33b9b18",t._sentryDebugIdIdentifier="sentry-dbid-cf43cf49-168c-4157-a9f0-8c25f33b9b18")}catch{}})();const v=f({__name:"App",setup(t){const a=r(),e=c();return e.actions.fetch(),i(()=>a.jwt,e.actions.fetch),(w,y)=>{const s=p("RouterView");return o(e).state.workspace?(m(),u(n,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:d(()=>[_(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):l("",!0)}}});export{v as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang.b1caf985.js.map
