[data-v-1c0a4c2f]:root{--main-font-family: DM Sans, sans-serif}[data-v-1c0a4c2f]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-1c0a4c2f]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-1c0a4c2f]{background-color:#fff;padding:10px}.files-navigator[data-v-1c0a4c2f]{display:flex;flex-direction:column;gap:20px}.files-navigator .scroll-area[data-v-1c0a4c2f]{border:1px solid lightgray;border-radius:6px}.files-navigator .file-size[data-v-1c0a4c2f]{color:#8692a5;margin-left:5px}.files-navigator .char-match[data-v-1c0a4c2f]{background-color:#ffee56}.files-navigator[data-v-1c0a4c2f] .ant-tree{height:100%}
