import{O as r}from"./userStore.e6231111.js";import{d as l,J as i,K as c,b as a,w as n,u as o,o as u,az as d,d6 as f,d5 as _}from"./index.e310aebb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="48c2e860-f018-49ed-8671-79a41c6da601",e._sentryDebugIdIdentifier="sentry-dbid-48c2e860-f018-49ed-8671-79a41c6da601")}catch{}})();const w=l({__name:"OidcLoginCallback",setup(e){return i(async()=>{await new r().loginCallback()}),(t,s)=>(u(),c("div",null,[a(o(f),null,{default:n(()=>[d("You're authenticated")]),_:1}),a(o(_),null,{default:n(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.617bb1cd.js.map
