import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.558db144.js";import{d as m,e3 as f,e4 as g,K as y,b,u as n,o as w,Q as k}from"./index.e310aebb.js";import{u as h}from"./workspaceStore.9673015c.js";import"./userStore.e6231111.js";import"./CircularLoading.f21c2905.js";import"./Logo.afdc4154.js";import"./string.a01d17aa.js";import"./index.1acd89cf.js";import"./url.fb968ca0.js";import"./colorHelpers.0fc16894.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="201082e4-4765-46fd-a023-8790f24dda23",e._sentryDebugIdIdentifier="sentry-dbid-201082e4-4765-46fd-a023-8790f24dda23")}catch{}})();const v={class:"runner"},I=m({__name:"Login",setup(e){const o=f(),t=g(),r=h(),_=async()=>{const{redirect:a,...s}=t.query;if(a){await o.push({path:a,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>{var c,d,p,u,i;return w(),y("div",v,[b(l,{"logo-url":(d=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(p=n(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const H=k(I,[["__scopeId","data-v-cb33c596"]]);export{H as default};
//# sourceMappingURL=Login.d7be1284.js.map
