import{_ as d}from"./TasksView.vue_vue_type_script_setup_true_lang.dee39276.js";import{L as p}from"./tasksController.c1e326d3.js";import{d as f,f as u,c as _,w as t,o as m,b as s,u as o,d6 as y,az as i,bM as b,da as k,Q as w}from"./index.e310aebb.js";import{C as g}from"./ContentLayout.991bbf22.js";import{a as T}from"./ant-design.e632b777.js";import"./metadata.0be16082.js";import"./PhWebhooksLogo.vue.9a797838.js";import"./string.a01d17aa.js";import"./index.850d1dd3.js";import"./dayjs.ef81895b.js";import"./gateway.4d0dc75b.js";import"./popupNotifcation.fa3e65fc.js";import"./linters.686aafeb.js";import"./asyncComputed.6b1d4165.js";import"./scripts.745c4bc0.js";import"./record.d2935dfa.js";import"./polling.debfe6c7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="a2c6d489-6dc4-47ab-a2e4-c802bb0503f3",e._sentryDebugIdIdentifier="sentry-dbid-a2c6d489-6dc4-47ab-a2e4-c802bb0503f3")}catch{}})();const x=f({__name:"Tasks",setup(e){const a=new p,r=u(null);async function l(){var n;await T("Are you sure you want to clear all tasks and their associated payloads?")&&await((n=r.value)==null?void 0:n.clearAllTasks())}return(c,n)=>(m(),_(g,null,{default:t(()=>[s(o(k),{justify:"space-between",align:"center"},{default:t(()=>[s(o(y),null,{default:t(()=>[i("Tasks")]),_:1}),s(o(b),{type:"link",style:{"margin-top":"10px"},onClick:l},{default:t(()=>[i("Clear all")]),_:1})]),_:1}),s(d,{ref_key:"tasksTableView",ref:r,class:"tasks",api:o(a),stages:null,editor:""},null,8,["api"])]),_:1}))}});const $=w(x,[["__scopeId","data-v-4b92e2a9"]]);export{$ as default};
//# sourceMappingURL=Tasks.678a26f4.js.map
