import{d as i,c as p,w as m,o as n,b as a,u as t}from"./index.e310aebb.js";import"./linters.686aafeb.js";import{W as s}from"./workspaces.c03334c7.js";import{C as d}from"./ContentLayout.991bbf22.js";import{E as f}from"./controller.b35b6237.js";import{_ as c}from"./View.vue_vue_type_script_setup_true_lang.4d91a15c.js";import"./asyncComputed.6b1d4165.js";import"./workspaceStore.9673015c.js";import"./userStore.e6231111.js";import"./url.fb968ca0.js";import"./colorHelpers.0fc16894.js";import"./record.d2935dfa.js";import"./gateway.4d0dc75b.js";import"./popupNotifcation.fa3e65fc.js";import"./fetch.ac0cc198.js";import"./PhPencil.vue.001dc101.js";import"./SaveButton.3679bfe7.js";import"./UnsavedChangesHandler.b4b7d195.js";import"./ExclamationCircleOutlined.ba1bd806.js";import"./CrudView.f8c62bd5.js";import"./router.2399bbbf.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.d13fff5d.js";import"./PhDotsThreeVertical.vue.86ea10eb.js";import"./Badge.a954551a.js";import"./index.3d882fa8.js";import"./index.850d1dd3.js";import"./polling.debfe6c7.js";import"./omniChatStore.755c548d.js";import"./index.1acd89cf.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="7ed6ca24-20b2-4bb7-8045-0ffb9b87a5c8",o._sentryDebugIdIdentifier="sentry-dbid-7ed6ca24-20b2-4bb7-8045-0ffb9b87a5c8")}catch{}})();const J=i({__name:"EnvVarsEditor",setup(o){const r=new f;return(e,b)=>(n(),p(d,null,{default:m(()=>[a(c,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{J as default};
//# sourceMappingURL=EnvVarsEditor.2eb2eb57.js.map
