import{d,el as i,g as r,o,K as t,F as c,ec as f,eb as g,Q as p}from"./index.e310aebb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="5763c385-fd2f-4767-ae7f-aaefcbc2c92f",e._sentryDebugIdIdentifier="sentry-dbid-5763c385-fd2f-4767-ae7f-aaefcbc2c92f")}catch{}})();const u={class:"logo"},_=["src","alt"],m=d({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const s=e;i(a=>({"4521d904":n.value}));const n=r(()=>s.size==="small"?"24px":s.size==="large"?"80px":"50px"),l=r(()=>`${s.brandName} Logo`);return(a,y)=>(o(),t("div",u,[a.imageUrl?(o(),t("img",{key:0,class:"logo-img",src:a.imageUrl,alt:l.value},null,8,_)):c("",!0),a.hideText?c("",!0):(o(),t("span",{key:1,class:f(a.size)},g(a.brandName),3))]))}});const h=p(m,[["__scopeId","data-v-8f34aac0"]]);export{h as L};
//# sourceMappingURL=Logo.afdc4154.js.map
