import{O as a,R as s}from"./OmniChat.87d49e85.js";import{d,e4 as i,o as c,c as p,u as n}from"./index.e310aebb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="3a88780a-22fa-45e3-9ad4-3a1133ddeeb1",e._sentryDebugIdIdentifier="sentry-dbid-3a88780a-22fa-45e3-9ad4-3a1133ddeeb1")}catch{}})();const _=d({__name:"ConsoleOmniChat",setup(e){const t=i().params.projectId,r=new s(t);return(u,f)=>(c(),p(a,{"ai-chat-repository":n(r),environment:{origin:"console",projectId:n(t)}},null,8,["ai-chat-repository","environment"]))}});export{_};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang.07e0ccc5.js.map
