from .agent import get_player_bp as role_agent_player_bp
from .client import get_editor_bp as role_client_editor_bp
from .client import get_player_bp as role_client_player_bp

__all__ = ["role_agent_player_bp", "role_client_player_bp", "role_client_editor_bp"]
