import{d as u,o as l,c as d,w as t,b as s,u as a,da as o,c_ as _,az as r,F as p,d5 as c,eb as i,ec as b,Q as y}from"./index.e310aebb.js";import{A as g}from"./Avatar.004ed8a2.js";import{C}from"./Card.adf1677c.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="034c6489-ea26-4f7c-89ef-b8b480379bf4",n._sentryDebugIdIdentifier="sentry-dbid-034c6489-ea26-4f7c-89ef-b8b480379bf4")}catch{}})();const m=u({__name:"ConnectorCard",props:{title:{},logoUrl:{},description:{},unavailable:{type:Boolean}},setup(n){return(e,f)=>(l(),d(a(C),{class:b({"connector-card":!0,unavailable:e.unavailable})},{default:t(()=>[s(a(o),{style:{width:"100%"},vertical:"",gap:12},{default:t(()=>[s(a(o),{justify:"space-between"},{default:t(()=>[s(a(g),{src:e.logoUrl,shape:"square",size:"large"},null,8,["src"]),e.unavailable?(l(),d(a(_),{key:0,style:{height:"fit-content"}},{default:t(()=>[r("Talk to us")]),_:1})):p("",!0)]),_:1}),s(a(o),{vertical:""},{default:t(()=>[s(a(c),{strong:""},{default:t(()=>[r(i(e.title),1)]),_:1}),s(a(c),{type:"secondary"},{default:t(()=>[r(i(e.description),1)]),_:1})]),_:1})]),_:1})]),_:1},8,["class"]))}});const I=y(m,[["__scopeId","data-v-e3719550"]]);export{I as C};
//# sourceMappingURL=ConnectorCard.3a0f0810.js.map
