import{d as c,g as b,o as r,c as d,w as a,b as l,u as n,da as i,O as p,F as f,em as u,en as g,bM as y,aP as m,e5 as _}from"./index.e310aebb.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="457abafb-e020-431f-9f65-f3d3ee951ad3",t._sentryDebugIdIdentifier="sentry-dbid-457abafb-e020-431f-9f65-f3d3ee951ad3")}catch{}})();const w=c({__name:"AbstraButton",props:{disabledTooltip:{},tooltip:{},prefixCls:{},type:{},htmlType:{},shape:{},size:{},loading:{type:[Boolean,Object]},disabled:{type:Boolean},ghost:{type:Boolean},block:{type:Boolean},danger:{type:Boolean},icon:{},href:{},target:{},title:{},onClick:{type:[Function,Array]},onMousedown:{type:[Function,Array]}},setup(t){const e=t,s=b(()=>e.disabledTooltip&&e.disabled?e.disabledTooltip:e.tooltip);return(o,k)=>s.value?(r(),d(n(m),{key:0,title:s.value},{default:a(()=>[l(n(y),u(g(o.$props)),{default:a(()=>[l(n(i),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[o.loading?f("",!0):p(o.$slots,"default",{key:0})]),_:3})]),_:3},16)]),_:3},8,["title"])):(r(),d(n(y),u(_({key:1},o.$props)),{default:a(()=>[l(n(i),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[o.loading?f("",!0):p(o.$slots,"default",{key:0})]),_:3})]),_:3},16))}});export{w as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.cbbef791.js.map
