import{d as b,e3 as m,e4 as p,o as c,c as f,w as l,K as _,ea as g,b as y,a as v,eb as w,u as n,aL as k}from"./index.e310aebb.js";import{A as I,T}from"./TabPane.9d204c54.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="c847e6b8-fb71-4a8c-9c76-6c805849467a",e._sentryDebugIdIdentifier="sentry-dbid-c847e6b8-fb71-4a8c-9c76-6c805849467a")}catch{}})();const S=b({__name:"TablesTabs",setup(e){const a=m(),t=p(),u=String(t.name),d=t.params.projectId,r=[{label:"Tables list",value:"tables"},{label:"Diagram view",value:"tables-diagram"},{label:"Run SQL",value:"sql"}],i=o=>{a.push({name:String(o),params:{projectId:d}})};return(o,D)=>(c(),f(n(T),{"active-key":n(u),options:r,"onUpdate:activeKey":i},{default:l(()=>[(c(),_(k,null,g(r,s=>y(n(I),{key:s.value,name:s.value},{tab:l(()=>[v("span",null,w(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{S as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang.7d1be8e5.js.map
