.source-code-container[data-v-330a6c89]{display:flex;flex-direction:column;gap:10px;height:100%;overflow:hidden;position:relative;box-sizing:border-box;border-radius:8px}.source-code-container .file-input[data-v-330a6c89]{margin-bottom:0;flex-grow:1}.source-code-container .monaco-element[data-v-330a6c89]{height:100%;width:100%;box-sizing:border-box;position:absolute}.source-code-container .monaco-element.hide[data-v-330a6c89]{display:none}.source-code-container .monaco-element.blur[data-v-330a6c89]{filter:blur(8px);pointer-events:none}.source-code-container .code-container[data-v-330a6c89]{width:100%;height:100%;position:relative;border:1px solid lightgray;border-radius:8px}.source-code-container .not-found-container[data-v-330a6c89]{position:absolute;z-index:2;width:100%;height:100%;display:flex;justify-content:center;align-items:center}.source-code-container .clickable[data-v-330a6c89]{cursor:pointer;display:flex;align-items:center;gap:8px}.source-code-container[data-v-330a6c89] .executing-line{background-color:#0000ff1a;border:1px solid blue}.source-code-container[data-v-330a6c89] .error-line{background-color:#ff00001a;border:1px solid orangered}
