import{d as a,o as d,K as o,b as s,u as r,br as _,Q as c}from"./index.e310aebb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="d899ca9d-b5e2-4a12-955f-f44bc5214d0b",e._sentryDebugIdIdentifier="sentry-dbid-d899ca9d-b5e2-4a12-955f-f44bc5214d0b")}catch{}})();const i={class:"centered"},f=a({__name:"LoadingContainer",setup(e){return(n,t)=>(d(),o("div",i,[s(r(_))]))}});const p=c(f,[["__scopeId","data-v-52e6209a"]]);export{p as L};
//# sourceMappingURL=LoadingContainer.3f93bcc6.js.map
