import{B as m}from"./BaseLayout.282c61a4.js";import{d as n,e4 as a,r as s,c,w as r,o as d,b as i,u as f}from"./index.e310aebb.js";import{N as u,_}from"./Navbar.f844e4dd.js";import"./OmniChat.87d49e85.js";import"./gateway.4d0dc75b.js";import"./popupNotifcation.fa3e65fc.js";import"./AbstraLogo.vue_vue_type_script_setup_true_lang.280ece81.js";import"./Logo.afdc4154.js";import"./uuid.ba72b934.js";import"./PhClockCounterClockwise.vue.5bb0d662.js";import"./omniChatStore.755c548d.js";import"./record.d2935dfa.js";import"./LoadingOutlined.c81a4534.js";import"./linters.686aafeb.js";import"./asyncComputed.6b1d4165.js";import"./columns.b1346706.js";import"./string.a01d17aa.js";import"./controller.5f18771c.js";import"./vue-flow-core.f0b1d635.js";import"./validations.6d3f69e1.js";import"./metadata.0be16082.js";import"./PhWebhooksLogo.vue.9a797838.js";import"./controller.b35b6237.js";import"./fetch.ac0cc198.js";import"./PhPencil.vue.001dc101.js";import"./requirements.3213c72b.js";import"./scripts.745c4bc0.js";import"./PhCopySimple.vue.134b5c12.js";import"./index.76147594.js";import"./Avatar.004ed8a2.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang.cbbef791.js";import"./PhArrowCounterClockwise.vue.43e81e96.js";import"./PhFilePy.vue.5eee52d4.js";import"./PhChats.vue.e1b07b2c.js";import"./PhRocket.vue.34f3249f.js";import"./PhPackage.vue.7b750514.js";import"./workspaces.c03334c7.js";import"./workspaceStore.9673015c.js";import"./userStore.e6231111.js";import"./url.fb968ca0.js";import"./colorHelpers.0fc16894.js";import"./polling.debfe6c7.js";import"./PhArrowSquareOut.vue.2585952a.js";import"./PhSignOut.vue.024a2a22.js";import"./PhSparkle.vue.56c31c6f.js";import"./editor.8fcb8d02.js";import"./index.3d882fa8.js";import"./CloseCircleOutlined.ba3cdc4b.js";import"./CheckCircleFilled.8ed73a12.js";import"./index.1acd89cf.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="40cd5915-b12e-40ee-bacf-0cfc2dd0961e",t._sentryDebugIdIdentifier="sentry-dbid-40cd5915-b12e-40ee-bacf-0cfc2dd0961e")}catch{}})();const ft=n({__name:"Workspace",setup(t){const o=a();return(e,l)=>{const p=s("RouterView");return d(),c(m,null,{navbar:r(()=>[i(u,{"page-title":f(o).meta.title},null,8,["page-title"])]),content:r(()=>[i(p)]),chat:r(()=>[i(_)]),_:1})}}});export{ft as default};
//# sourceMappingURL=Workspace.ea3a4c3e.js.map
