import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.dee39276.js";import{R as f}from"./tasksController.c1e326d3.js";import{d as _,e4 as b,g,K as y,b as w,w as k,u as n,c as I,F as T,aL as v,o as l,az as B,d6 as j}from"./index.e310aebb.js";import"./gateway.4d0dc75b.js";import{a as x,B as C}from"./build.a0b29d81.js";import{a as D}from"./project.3b35cd7f.js";import"./columns.b1346706.js";import{a as R}from"./asyncComputed.6b1d4165.js";import"./metadata.0be16082.js";import"./PhWebhooksLogo.vue.9a797838.js";import"./ant-design.e632b777.js";import"./string.a01d17aa.js";import"./index.850d1dd3.js";import"./dayjs.ef81895b.js";import"./linters.686aafeb.js";import"./scripts.745c4bc0.js";import"./record.d2935dfa.js";import"./polling.debfe6c7.js";import"./popupNotifcation.fa3e65fc.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="46e89e0f-3b37-43c0-af2f-4330c3501ae7",e._sentryDebugIdIdentifier="sentry-dbid-46e89e0f-3b37-43c0-af2f-4330c3501ae7")}catch{}})();const U=_({__name:"Tasks",setup(e){const a=b().params.projectId,p=new f(a),{result:o}=R(async()=>{const r=(await x.list(a)).find(d=>d.latest);if(!r)return null;const[u,c]=await Promise.all([C.get(r.id),D.get(a)]);return{buildSpec:u,project:c}}),i=g(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(l(),y(v,null,[w(n(j),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(l(),I(m,{key:0,class:"tasks",api:n(p),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{U as default};
//# sourceMappingURL=Tasks.54e3a51a.js.map
