.status-tag[data-v-4372bea0]{display:flex;justify-content:center;width:80px}.agents-grid[data-v-f3283209]{display:grid;grid-template-columns:repeat(auto-fill,minmax(300px,1fr));gap:20px}.status-tag[data-v-f3283209]{display:flex;justify-content:center;width:80px}
