import{m as n,n as a,T as r,p as o,P as p,C as d,M as c,s as m,q as s,t as u,v as f,x as g,y}from"./index.e310aebb.js";import{s as l}from"./userStore.e6231111.js";import{_ as b}from"./App.vue_vue_type_style_index_0_lang.b1caf985.js";import{a as i}from"./workspaceStore.9673015c.js";import"./PlayerConfigProvider.4862e88a.js";import"./colorHelpers.0fc16894.js";import"./index.f0e26865.js";import"./url.fb968ca0.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="1c5c07c4-1506-4026-9d79-4131245b688a",t._sentryDebugIdIdentifier="sentry-dbid-1c5c07c4-1506-4026-9d79-4131245b688a")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await l();const t=n(),e=a({render:()=>u(b)});r.init(),o(e,i),w.init(),e.use(i),e.use(t),e.use(p),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",c),e.component("Message",m),s(e,f),s(e,g),s(e,y)})();
//# sourceMappingURL=player.1aa90b4c.js.map
