import{C as r,E as t,K as i,a as f,M as b,c as l,P as y,R as c,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.05c667ab.js";import"./index.e310aebb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="ba172e5e-f336-492d-92f4-d7bddef01247",e._sentryDebugIdIdentifier="sentry-dbid-ba172e5e-f336-492d-92f4-d7bddef01247")}catch{}})();export{r as CancellationTokenSource,t as Emitter,i as KeyCode,f as KeyMod,b as MarkerSeverity,l as MarkerTag,y as Position,c as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.79c6f15a.js.map
